@@ -4,6 +4,7 @@ from ..util import _doc_params, _read_to_str
 from scanpy.readwrite import read
 from scanpy import settings
 from textwrap import indent
+from ..io import upgrade_schema
 
 HERE = Path(__file__).parent
 
@@ -26,6 +27,7 @@ def wu2020() -> AnnData:
     url = "https://github.com/icbi-lab/scirpy/releases/download/d0.1.0/wu2020.h5ad"
     filename = settings.datasetdir / "wu2020.h5ad"
     adata = read(filename, backup_url=url)
+    upgrade_schema(adata)
     return adata
 
 
@@ -45,11 +47,10 @@ def wu2020_3k() -> AnnData:
 
     {processing_code}
     """
-    # os.makedirs(settings.datasetdir, exist_ok=True)
-    # TODO host it on github or similar
     url = "https://github.com/icbi-lab/scirpy/releases/download/d0.1.0/wu2020_3k.h5ad"
     filename = settings.datasetdir / "wu2020_3k.h5ad"
     adata = read(filename, backup_url=url)
+    upgrade_schema(adata)
     return adata
 
 
@@ -78,4 +79,5 @@ def maynard2020() -> AnnData:
     url = "https://github.com/icbi-lab/scirpy/releases/download/d0.1.0/maynard2020.h5ad"
     filename = settings.datasetdir / "maynard2020.h5ad"
     adata = read(filename, backup_url=url)
+    upgrade_schema(adata)
     return adata
