@@ -6,6 +6,7 @@ from scirpy.util import (
     _is_symmetric,
     _translate_dna_to_protein,
 )
+from scirpy.util._negative_binomial import fit_nbinom
 from scirpy.util.graph import (
     igraph_from_sparse_matrix,
     layout_components,
@@ -288,3 +289,20 @@ def test_igraph_from_adjacency(matrix, is_symmetric, simplify):
             npt.assert_equal(matrix.toarray(), matrix_roundtrip.toarray())
     else:
         npt.assert_equal(matrix.toarray(), matrix_roundtrip.toarray())
+
+
+@pytest.mark.parametrize(
+    "X,expected",
+    [
+        (
+            np.array(
+                "4 2 7 3 1 2 5 0 4 3 6 0 5 4 0 5 2 2 4 4 1 4 3 1 4 2 5 5 7 3 4 3 4 2 3 10 "
+                "1 3 4 3 7 4 2 3 1 5 1 5 2 7 3 3 8 6 4 5 3 2 2 3 2 5 1 3 1 4 3 2 5 1 5 3 4 "
+                "1 5 2 2 2 4 1 5 8 7 3 1 2 1 3 1 6 6 6 1 3 3 0 2 2 5 4".split()
+            ).astype(int),
+            ([18.4954044, 0.8462615]),
+        )
+    ],
+)
+def test_fit_negative_binomial(X, expected):
+    npt.assert_almost_equal(fit_nbinom(X), expected, decimal=5)
